summaryrefslogtreecommitdiffstats
path: root/konversation/src/nicksonlineitem.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-08-20 20:20:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-08-20 20:20:19 +0000
commitdf6d1c3c6fd22031d432af447798938c1d7e1877 (patch)
tree4f74f2a214b347b651f6df4cee9d3e47dbfa84db /konversation/src/nicksonlineitem.cpp
parent449e0b1b356e63cb4869fc6e0020134efa83825d (diff)
downloadkonversation-df6d1c3c6fd22031d432af447798938c1d7e1877.tar.gz
konversation-df6d1c3c6fd22031d432af447798938c1d7e1877.zip
TQt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/konversation@1166088 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'konversation/src/nicksonlineitem.cpp')
-rw-r--r--konversation/src/nicksonlineitem.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/konversation/src/nicksonlineitem.cpp b/konversation/src/nicksonlineitem.cpp
index cd8cd1d..1ad2824 100644
--- a/konversation/src/nicksonlineitem.cpp
+++ b/konversation/src/nicksonlineitem.cpp
@@ -12,13 +12,13 @@
#include "nicksonlineitem.h"
-NicksOnlineItem::NicksOnlineItem(int type, QListView* parent, const QString& name, const QString& col2) :
+NicksOnlineItem::NicksOnlineItem(int type, TQListView* parent, const TQString& name, const TQString& col2) :
KListViewItem(parent, name, col2)
{
m_type=type;
}
-NicksOnlineItem::NicksOnlineItem(int type, QListViewItem* parent, const QString& name, const QString& col2) :
+NicksOnlineItem::NicksOnlineItem(int type, TQListViewItem* parent, const TQString& name, const TQString& col2) :
KListViewItem(parent, name, col2)
{
m_type=type;
@@ -26,12 +26,12 @@ NicksOnlineItem::NicksOnlineItem(int type, QListViewItem* parent, const QString&
/**
* Reimplemented to make sure, "Offline" items always get sorted to the bottom of the list
* @param i Pointer to the QListViewItem to compare with.
* @param col The column to compare
* @param ascending Specify sorting direction
* @return -1 if this item's value is smaller than i, 0 if they are equal, 1 if it's greater
*/
-int NicksOnlineItem::compare(QListViewItem* i,int col,bool ascending) const
+int NicksOnlineItem::compare(TQListViewItem* i,int col,bool ascending) const
{
// if we are the Offline item, make sure we get sorted at the end of the list
if(m_type==OfflineItem) return ascending ? 1 : -1;
@@ -26,12 +26,12 @@ NicksOnlineItem::NicksOnlineItem(int type, QListViewItem* parent, const QString&
/**
* Reimplemented to make sure, "Offline" items always get sorted to the bottom of the list
- * @param i Pointer to the QListViewItem to compare with.
+ * @param i Pointer to the TQListViewItem to compare with.
* @param col The column to compare
* @param ascending Specify sorting direction